pub async fn correct(
db: &Surreal<Db>,
weights: &ProvenanceWeights,
target: &CorrectTarget,
correction: Correction,
) -> Result<CorrectionReport, GraphError>Expand description
Apply a correction, or report why it was refused.
pub async fn correct(
db: &Surreal<Db>,
weights: &ProvenanceWeights,
target: &CorrectTarget,
correction: Correction,
) -> Result<CorrectionReport, GraphError>Apply a correction, or report why it was refused.