pub async fn views(
db: &Surreal<Db>,
cache: &mut NameCache,
relationships: &[Relationship],
) -> Result<Vec<EdgeView>, GraphError>Expand description
Render relationships for a human, sharing one name cache.
pub async fn views(
db: &Surreal<Db>,
cache: &mut NameCache,
relationships: &[Relationship],
) -> Result<Vec<EdgeView>, GraphError>Render relationships for a human, sharing one name cache.