pub struct TypeGroup {
pub entity_type: String,
pub count: u64,
pub top: Vec<KnownEntity>,
}Expand description
One entity type, and the strongest entities in it.
Fields
entity_type: Stringcount: u64How many entities of this type exist, not how many are listed.
top: Vec<KnownEntity>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for TypeGroup
impl<'de> Deserialize<'de> for TypeGroup
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for TypeGroup