pub struct MigrationReport {
pub from_version: i64,
pub to_version: i64,
pub edges_backfilled: u64,
}Expand description
What one migration pass did. edges_backfilled is zero on an already
current store.
Fields
from_version: i64Schema version the store was at when the pass started.
to_version: i64Schema version the store is at now.
edges_backfilled: u64Number of edges that gained evidence counts in this pass.
Implementations