pub async fn daemon_stop(memory_dir: &Path) -> Result<(), RecallError>Expand description
Stop the daemon serving this graph, if one is running.
pub async fn daemon_stop(memory_dir: &Path) -> Result<(), RecallError>Stop the daemon serving this graph, if one is running.