pub async fn run(options: ServeOptions) -> Result<(), RecallError>Expand description
Run the daemon until it is asked to stop or goes idle.
pub async fn run(options: ServeOptions) -> Result<(), RecallError>Run the daemon until it is asked to stop or goes idle.