pub struct OverviewArgs {
pub per_type: usize,
}Expand description
How much of the graph an overview lists per entity type. Absent — the shape a client that does not care sends — takes the default.
Fields
per_type: usizeTrait Implementations
Sourceimpl Clone for OverviewArgs
impl Clone for OverviewArgs
Sourcefn clone(&self) -> OverviewArgs
fn clone(&self) -> OverviewArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OverviewArgs
impl Debug for OverviewArgs
Sourceimpl<'de> Deserialize<'de> for OverviewArgs
impl<'de> Deserialize<'de> for OverviewArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for OverviewArgs
impl PartialEq for OverviewArgs
Sourceimpl Serialize for OverviewArgs
impl Serialize for OverviewArgs
impl StructuralPartialEq for OverviewArgs